function [locs, desc, chogFeatures] = ParseCHoGFile(rootImageDir, rootFeatureDBDir, object, camera, imageID)


    % rootImageDir = The directory with the BMW database
    % rootFeatureDBDir = The directory with the SURF features. i.e. BMW_SIFT
    % object = string with the object category. For ex., campinile, bowles, etc.
    % camera = string with the camera number. For ex., 00, 01, 02, 03, 04
    % imageID = string with the image number. For ex., 0000, 0001, ...
    
    pathToFile = [rootFeatureDBDir '/' object '/' camera '/' imageID '.txt'];
    pathToImag = [rootImageDir '/' object '/' camera '/' imageID '.jpg'];
    features = load(pathToFile);
    
    % Create the two output matrices (use known size for efficiency)
    locs = features(:,1:4); %row col scale ori
    descriptors = features(:,6:end); %45 element vector
    chogFeatures = [];
    desc = [];
    
    for i = 1:size(locs,1)
        chogFeatures(i).location = locs(i,1:2);
        chogFeatures(i).scale = locs(i,3);
        chogFeatures(i).orientation = locs(i,4);
        chogFeatures(i).descriptor = descriptors(i,:);
        desc = [desc; descriptors(i,:)];
    end
    locs = locs(:, 1:2);
    
    % Plot the image and the features
    im = imread(pathToImag);
    figure(1); clf; imshow(im); hold on; plot(locs(:,1), locs(:,2), 'rx');
end